<?php
/*
	Plugin Name: Fixdigital, elementor whatsapp
	Description: Additional 'FixDigital WhatsApp' element for Elementor.
	Version: 0.2.2
	Author: fixdigital
	License:     GPL2
	License URI: https://www.gnu.org/licenses/gpl-2.0.html
	Text Domain: fix-whatsapp-elementor
	Domain Path: /languages/
 */


namespace FixWhatsAppElementor;

use FixWhatsAppElementor\Widgets\FixWhatsApp_3_1_0_Plus;
use FixWhatsAppElementor\Widgets\FixWhatsApp_Between_3_1_0_And_2_9_0;
use FixWhatsAppElementor\Widgets\FixWhatsApp_Before_2_9_0;


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Plugin {

	public $version;

	protected $assetsUrl;

	public function __construct()
    {
        // set plugin version
        $pluginData     = get_file_data( __FILE__, array( 'Version' => 'Version' ), false );
        $this->version = isset( $pluginData['Version'] ) ? $pluginData['Version'] : '0.0.0';

        $this->assetsUrl = plugins_url( '/assets', __FILE__ );

        add_action( 'plugins_loaded', function(){
            load_plugin_textdomain( 'fix-whatsapp-elementor', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
        } );

        add_action( 'elementor/init', [ $this, 'elementorInit' ] );

        add_action( 'wp_enqueue_scripts', [ $this, 'enqueueStylesAndScripts' ] );
        add_action( 'elementor/editor/wp_head', [ $this, 'enqueueIconsStyles' ] );
	}


	public function elementorInit()
    {
        if (version_compare( ELEMENTOR_VERSION, '3.5.0', '>=')) {
            add_action('elementor/widgets/register' , [$this, 'registerWidgets']);
        } else {
            add_action('elementor/widgets/widgets_registered' , [$this, 'registerWidgets']);
        }

        $elManager = \Elementor\Plugin::instance()->elements_manager;
        $cats = $elManager->get_categories();

        if (!isset($cats['other-elements'])) {
            // Add element category in panel
            $elManager->add_category(
                'other-elements',
                [
                    'title' => __( 'Other elements' , 'fix-whatsapp-elementor' ),
                    'icon' => 'font',
                ],
                1
            );
        }
	}

	/**
	 * @param $manager Elementor\Widgets_Manager
	 *
	 */
	public function registerWidgets( $manager )
    {
        include_once 'widgets/FixWhatsApp.php';
        include_once 'widgets/FixWhatsApp_3_1_0_Plus.php';
        include_once 'widgets/FixWhatsApp_Between_3_1_0_And_2_9_0.php';
        include_once 'widgets/FixWhatsApp_Before_2_9_0.php';

        if (version_compare( ELEMENTOR_VERSION, '3.5.0', '>=')) {
            $manager->register( new FixWhatsApp_3_1_0_Plus() );
        } else if (version_compare( ELEMENTOR_VERSION, '3.1.0', '>=')) {
            $manager->register_widget_type( new FixWhatsApp_3_1_0_Plus() );
        } else if (version_compare( ELEMENTOR_VERSION, '2.9.0', '>=')) {
            $manager->register_widget_type( new FixWhatsApp_Between_3_1_0_And_2_9_0() );
        } else {
            $manager->register_widget_type( new FixWhatsApp_Before_2_9_0() );
        }
	}


    public function enqueueStylesAndScripts()
    {
        wp_enqueue_style('fix-whatsapp-elementor', $this->assetsUrl . '/css/main.css', null, $this->version );

        // it's mandatory that 'fix-whatsapp-elementor-js' script is run after the global variable: window.fxd_viewid
        // was initialized by fixdigital-integration plugin
        $deps = array('jquery');
        if (wp_script_is('FixdigitalIntegration', 'registered')) {
            $deps[] = 'FixdigitalIntegration';   // assembled script
        } else if (wp_script_is('addPageViewCrmInfoScript', 'registered')) {
            $deps[] = 'addPageViewCrmInfoScript';  // individual script
        }

        wp_register_script( 'fix-whatsapp-elementor-js', $this->assetsUrl . '/js/script.js', $deps, $this->version);
        wp_enqueue_script( 'fix-whatsapp-elementor-js' );

        $this->enqueueIconsStyles();

        $this->initDataForJsScript();
	}



    public function enqueueIconsStyles()
    {
        // try to connect the font awesome icons because they are absent in last versions of Elementor
        if ( defined('ELEMENTOR_ASSETS_URL') && version_compare( ELEMENTOR_VERSION, '2.5.0', '>=') ) {
            wp_enqueue_style(
                'font-awesome-5',
                ELEMENTOR_ASSETS_URL . 'lib/font-awesome/css/fontawesome.min.css',
                [],
                ''
            );

            wp_enqueue_style(
                'brands',
                ELEMENTOR_ASSETS_URL . 'lib/font-awesome/css/brands.min.css',
                [],
                ''
            );
        }
	}



    public function initDataForJsScript()
    {
        global $post;

         $blogId = 0;

        if (is_multisite()) {
            $blogId = (int) get_current_blog_id();
        }

        $data = array(
            'multisiteCrmId' => null,
            'blogId'         => $blogId,
            'pageId'         => $post ? $post->ID : 0,
            'projectTypeID'  => $this->getPagesType($blogId),
        );

        if (is_multisite()) {
            $msOptions = get_site_option( 'web_group_crm_options' , false );
            if (!empty($msOptions['multisiteCrmId'])) {
                $data['multisiteCrmId'] = $msOptions['multisiteCrmId'];
            }
        }

        if ($data['projectTypeID'] === 2) {
            $data['projectID'] = $data['pageId'];
        } else {
            $data['projectID'] = $data['blogId'];
        }

        // pass params from PHP to the included stript
        wp_localize_script( 'fix-whatsapp-elementor-js', 'fixdigitalWhatsAppElementorPluginData', $data );
    }


    /**
     * Returns:
     *    0 - if custom site or custom multisite
     *    1 - if our multisite's blog contains usual pages
     *    2 - if our multisite's blog contains landing pages
     *
     * @param $blogId
     *
     * @return int
     */
    public function getPagesType( $blogId )
    {
        if( $this->isCustomBlog() ){
            $type = 0;
        } else {
            $type     = 1;
            $blogType = get_blog_option( $blogId, 'uco_blog_type' );

            if( $blogType === 'landing-pages-catalog' ){
                $type = 2;
            }
        }

        return $type;
    }



    public function isCustomBlog()
    {
        $result = true;

        if (is_multisite() && get_site_option('isWebGroupUcoSite')) {
            $result = false;
        }

        return $result;
    }


}

new Plugin();


// init plugin update checker
require_once __DIR__ . '/plugin-update-checker/plugin-update-checker.php';
$myUpdateChecker = \Puc_v4_Factory::buildUpdateChecker(
    'https://wp-plugins.ln3.tempurl.info/plugin-update-checker/fixdigital-elementor-whatsapp.json',
    __FILE__, //Full path to the main plugin file
    'fixdigital-elementor-whatsapp'
);
